/*
 * 413_adc.h 
 * ADC related functions 
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#ifndef _P413_ADC_H
#define _P413_ADC_H

#include "413_config.h"

/**
 * Definition of the ADC registers by system
 * Page 631 of PICs' datasheet
 */
#define P413_ADC_STEERING_WHEEL_CLUTCH  0b001000    // RB0
#define P413_ADC_PLAUSABILITY_4         0b001011    // RB3
#define P413_ADC_PLAUSABILITY_3         0b001100    // RB4
#define P413_ADC_PLAUSABILITY_2         0b001101    // RB5
#define P413_ADC_PLAUSABILITY_1         0b000111    // RA7
#define P413_ADC_SUSPENSION_1           0b000011    // RA3
#define P413_ADC_SUSPENSION_2           0b001111    // RB7
#define P413_ADC_SUSPENSION_3           0b001110    // RB6
#define P413_ADC_SUSPENSION_4           0b101000    // RF0
#define P413_ADC_OIL_PRESSURE           0b101100    // RF4
#define P413_ADC_OIL_TEMPERATURE        0b101011    // RF3
#define P413_ADC_FUEL                   0b001010    // RB2
#define P413_ADC_HYDRAULIC              0b101001    // RF1
#define P413_ADC_AIR_PRESSURE           0b001001    // RB1
#define P413_ADC_ETC_SENSOR1            0b000101    // RA5
#define P413_ADC_ETC_SENSOR2            0b110110    // RG6
#define P413_ADC_TPS_SENSOR1            0b000100    // RA4
#define P413_ADC_TPS_SENSOR2            0b110111    // RG7

// Define of the GPIOs
#define STEERING_WHEEL_CLUTCH_TRIS      TRISBbits.TRISB0
#define STEERING_WHEEL_CLUTCH_ANSEL     ANSELBbits.ANSELB0
#define PLAUSABILITY_4_TRIS             TRISBbits.TRISB3
#define PLAUSABILITY_4_ANSEL            ANSELBbits.ANSELB3
#define PLAUSABILITY_3_TRIS             TRISBbits.TRISB4
#define PLAUSABILITY_3_ANSEL            ANSELBbits.ANSELB4
#define PLAUSABILITY_2_TRIS             TRISBbits.TRISB5
#define PLAUSABILITY_2_ANSEL            ANSELBbits.ANSELB5
#define PLAUSABILITY_1_TRIS             TRISAbits.TRISA7
#define PLAUSABILITY_1_ANSEL            ANSELAbits.ANSELA7
#define SUSPENSION_1_TRIS               TRISAbits.TRISA3
#define SUSPENSION_1_ANSEL              ANSELAbits.ANSELA3
#define SUSPENSION_2_TRIS               TRISBbits.TRISB7
#define SUSPENSION_2_ANSEL              ANSELBbits.ANSELB7
#define SUSPENSION_3_TRIS               TRISBbits.TRISB6
#define SUSPENSION_3_ANSEL              ANSELBbits.ANSELB6
#define SUSPENSION_4_TRIS               TRISFbits.TRISF0
#define SUSPENSION_4_ANSEL              ANSELFbits.ANSELF0
#define OIL_PRESSURE_TRIS               TRISFbits.TRISF4
#define OIL_PRESSURE_ANSEL              ANSELFbits.ANSELF4
#define OIL_TEMPERATURE_TRIS            TRISFbits.TRISF3
#define OIL_TEMPERATURE_ANSEL           ANSELFbits.ANSELF3
#define FUEL_TRIS                       TRISFbits.TRISF3
#define FUEL_ANSEL                      ANSELFbits.ANSELF3
#define HYDRAULIC_TRIS                  TRISFbits.TRISF1
#define HYDRAULIC_ANSEL                 ANSELFbits.ANSELF1
#define PRESS_TRIS                      TRISBbits.TRISB1
#define PRESS_ANSEL                     ANSELBbits.ANSELB1


/**
 * This function inits the ADC module of the microcontroller. The programmer must
 * do this function before try an ADC conversion 
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void init_ADC(void);


/**
 * This function returns the value of the selected input.
 * Remember the ADC resolution is 10 bits but we receive 8 bits.
 * 
 * Requires:
 *      - This function requires the number of an input
 * 
 * Returns:
 *      - Returns a uint8_t number with the conversed input
 */
inline uint8_t getADCValue( uint8_t adNumber );


#endif