/*
 * 413_clutch_gear.c 
 * Clutch ang gear related functions source code
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#include "413_clutch_gear.h"

/**
 * This function inits the clutch and gear system. We must do this function
 * before do any work with this system
 */
void init_clutch_gear(void)
{
    // Program the PWM system
    init_pwm();
    
    // Init cutoff
    CUTOFF_TRIS = INPUT;
    CUTOFF_WPU = 0;
    
    // Program the outputs for change the gear
    GEAR_UP_TRIS = OUTPUT;
    GEAR_UP_LAT = 0;
    GEAR_DOWN_TRIS = OUTPUT;
    GEAR_DOWN_ANSEL = DIGITAL;
    GEAR_DOWN_LAT = 0;
    
    // Program the inputs for know if we changed the gear
    GEAR_0_TRIS = INPUT;
    GEAR_0_WPU = 1;
    GEAR_2_TRIS = INPUT;
    GEAR_2_WPU = 1;
    GEAR_3_TRIS = INPUT;
    GEAR_3_WPU = 1;
}

/**
 * Set the power to the pneumatic valve to make air go out from system
 */
void clutchOut(uint8_t percent)
{
    // Correct possible wrong function calls
    if ( percent > 100)
        percent = 100;
    
    // Set the value to the PWM 6
    setPwm6( percent << 1 );
}

/**
 * Set the power to the pneumatic valve to put air into de system
 */
void clutchIn(uint8_t percent)
{
    // Correct possible wrong function calls
    if ( percent > 100)
        percent = 100;
    
    // Set the value to the PWM 7
    setPwm7( percent << 1 );
}

/**
 * Activate the normal preassure in the system for fast gear change
 */
void gearNormalPressure(void)
{
    // Set the value to the PWM 1
    setPwm1( FAST_GEAR_CHANGE );
}

/**
 * Activate the reduced preassure in the system for slow gear change, and
 * be able to reach the "No gear" position
 */
void gearNeutralPressure(void)
{
    // Set the value to the PWM 1
    setPwm1( SLOW_GEAR_CHANGE );
}

/**
 * Stops the pressure for change the gear. Is used for stop the current and do
 * not put hot the valve.
 */
void gearNoPressure(void)
{
    // Set the value to the PWM 1
    setPwm1( NO_GEAR_PRESSURE );
}

/**
 * Put the gear valve in the position to increment one gear. Be careful with
 * this function because there are not way to know if the movement was finish.
 */
void gearUp(void)
{
    // Activate the gear up coil
    GEAR_UP_LAT = 1;
    // Deactivate the gear down coil
    GEAR_DOWN_LAT = 0;
}

/**
 * Put the gear valve in the position to decrement one gear. Be careful with
 * this function because there are not way to know if the movement was finish.
 */
void gearDown(void)
{
     // Deactivate the gear up coil
    GEAR_UP_LAT = 0;
    // Activate the gear down coil
    GEAR_DOWN_LAT = 1;
}

/**
 * Put the gear valve in the passive position. Be careful with
 * this function because there are not way to know if the movement was finish.
 */
void gearMiddle(void)
{
    // Deactivate the gear up coil
    GEAR_UP_LAT = 0;
    // Deactivate the gear down coil
    GEAR_DOWN_LAT = 0;
}

/**
 * This function check if the motor is detecting the no gear position
 */
uint8_t checkNoGear(void)
{
    return (!GEAR_0_PORT);
}

/**
 * This function check if the motor is detecting the second gear
 */
uint8_t checkSecondGear(void)
{
    return (!GEAR_2_PORT);
}

/**
 * This function check if the motor is detecting the third gear position
 */
uint8_t checkThirdGear(void)
{
    return (!GEAR_3_PORT);
}

/**
 * This function deactivte the cutoff. Is a way to increment gear without the
 * clutch
 */
void deactivateCuttoff(void)
{
    CUTOFF_TRIS = INPUT;
}

/**
 * This function deactivte the cutoff. Is a way to increment gear without the
 * clutch
 */
void activateCuttoff(void)
{
    CUTOFF_TRIS = OUTPUT;
    CUTOFF_LAT = 0;
}
