/*
 * 413_dashboard.h 
 * Dashboard related functions 
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#ifndef _P413_DASHBOARD_H
#define _P413_DASHBOARD_H

#include "413_config.h"

// Ports definition
// RPM A
#define RPM_A_TRIS              TRISEbits.TRISE0
#define RPM_A_LAT               LATEbits.LATE0
#define RPM_A_PORT              PORTEbits.RE0
#define RPM_A_ANSEL             ANSELEbits.ANSELE0
// RPM B
#define RPM_B_TRIS              TRISEbits.TRISE1
#define RPM_B_LAT               LATEbits.LATE1
#define RPM_B_PORT              PORTEbits.RE1
#define RPM_B_ANSEL             ANSELEbits.ANSELE1
// RPM CLR
#define RPM_CLR_TRIS            TRISEbits.TRISE2
#define RPM_CLR_LAT             LATEbits.LATE2
#define RPM_CLR_PORT            PORTEbits.RE2
#define RPM_CLR_ANSEL           ANSELEbits.ANSELE2
// RPM CLk
#define CLK_TRIS                TRISGbits.TRISG0
#define CLK_LAT                 LATGbits.LATG0
#define CLK_PORT                PORTGbits.RG0
#define CLK_ANSEL               ANSELGbits.ANSELG0
// Dashboard A
#define DASHBOARD_A_TRIS        TRISGbits.TRISG3
#define DASHBOARD_A_LAT         LATGbits.LATG3
#define DASHBOARD_A_PORT        PORTGbits.RG3
#define DASHBOARD_A_ANSEL       ANSELGbits.ANSELG3
// Dashboard B
#define DASHBOARD_B_TRIS        TRISGbits.TRISG2
#define DASHBOARD_B_LAT         LATGbits.LATG2
#define DASHBOARD_B_PORT        PORTGbits.RG2
#define DASHBOARD_B_ANSEL       ANSELGbits.ANSELG2
// Dashboard CLR
#define DASHBOARD_CLR_TRIS      TRISGbits.TRISG1
#define DASHBOARD_CLR_LAT       LATGbits.LATG1
#define DASHBOARD_CLR_PORT      PORTGbits.RG1
#define DASHBOARD_CLR_ANSEL     ANSELGbits.ANSELG1
// Segments 1
#define SEGMENTS_1_TRIS         TRISFbits.TRISF5
#define SEGMENTS_1_LAT          LATFbits.LATF5
#define SEGMENTS_1_PORT         PORTFbits.RF5
#define SEGMENTS_1_ANSEL        ANSELFbits.ANSELF5
// Segments 2
#define SEGMENTS_2_TRIS         TRISFbits.TRISF6
#define SEGMENTS_2_LAT          LATFbits.LATF6
#define SEGMENTS_2_PORT         PORTFbits.RF6
#define SEGMENTS_2_ANSEL        ANSELFbits.ANSELF6
// Segments 3
#define SEGMENTS_3_TRIS         TRISFbits.TRISF7
#define SEGMENTS_3_LAT          LATFbits.LATF7
#define SEGMENTS_3_PORT         PORTFbits.RF7
#define SEGMENTS_3_ANSEL        ANSELFbits.ANSELF7
// Segments 4
#define SEGMENTS_4_TRIS         TRISGbits.TRISG7
#define SEGMENTS_4_LAT          LATGbits.LATG4
#define SEGMENTS_4_PORT         PORTGbits.RG7
#define SEGMENTS_4_ANSEL        ANSELGbits.ANSELG7


#define OIL_TEMPERATURE_ERROR_VALUE     230
#define OIL_PRESSURE_ERROR_VALUE        210
#define AIR_PRESSURE_ERROR_VALUE        50
#define FUEL_ERROR_VALUE                100
#define WATER_TEMPERATURE_ERROR_VALUE    99

/**
 * This functions inits the serial to parallel circuit for handle the
 * dashboard
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void init_dashboard(void);

// Dashboard LED positoin defines
#define DASHBOARD_OIL_TEMPERATURE   0x0100
#define DASHBOARD_FUEL_PUMP         0x0200
#define DASHBOARD_OIL_PRESSURE      0x0400
#define DASHBOARD_RESV_ORANGE       0x0800
#define DASHBOARD_ETC_APPS          0x1000
#define DASHBOARD_FUEL_LEVEL        0x2000
#define DASHBOARD_AIR_PRSSURE       0x4000
#define DASHBOARD_WATER_TEMPERATURE 0x8000

// Preload button and system port defines
#define PRELOAD_BUTTON_TRIS         TRISDbits.TRISD1
#define PRELOAD_BUTTON_ANSEL        ANSELDbits.ANSELD1
#define PRELOAD_BUTTON_PORT         PORTDbits.RD1
#define PRELOAD_ACTIVATION_TRIS     TRISEbits.TRISE7
#define PRELOAD_ACTIVATION_ANSEL    ANSELEbits.ANSELE7
#define PRELOAD_ACTIVATION_LAT      LATEbits.LATE7

/**
 * This function updates the values of the dashboard information
 * Uses the local variable "dashboard_value" and the "rpm_value"
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void updateDashboard(void);

/**
 * This function sets the LED that indicates the state of the fuel pump
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setFuelPump(uint8_t state);

/**
 * This function sets the LED that indicates the state of the oil temperature
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setOilTemperature(uint8_t state);

/**
 * This function sets the LED that indicates the state of the oil pressure
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setOilPressure(uint8_t state);

/**
 * This function sets the LED that indicates the state of the Resv system. If
 * this system is not implemented, it will be an extra output to handle systems
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setResvOrange(uint8_t state);

/**
 * This function sets the LED that indicates the state of the air pressure
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setAirPressure(uint8_t state);

/**
 * This function sets the LED that indicates the state of the fuel level
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setFuelLevel(uint8_t state);

/**
 * This function sets the LED that indicates the state of the security system
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setEtcApps(uint8_t state);



/**
 * This function sets the LED that indicates the state of the water temperature
 * 
 * Requires:
 *      - A variable uint8_t with TRUE if the LED will be on, or FALSE if will
 *      - be off
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setWaterTemperature(uint8_t state);

/**
 * This function sets a number to send to the 7 segments
 * 
 * Requires:
 *      - A uint8_t variable withnumber from the 0 to the 9 with the number
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setNumberSegments(uint8_t number);

/**
 * Sets the rpm value
 * 
 * Requires:
 *      - A uint8_t varaible with anumber from the 0 to the 0 with the number of
 *        leds the program wants activate
 *        
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setRpm(uint8_t rpm);

/**
 * Set the system to activate the gear 7 segments
 * 
 * Requires:
 *      - This functions doesn't requires anything
 *        
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setTrisLedOnGear(void);

/**
 * Set the system to activate the lowest 7 segments of the motor temperature
 * 
 * Requires:
 *      - This functions doesn't requires anything
 *        
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setTrisLedTemperature1(void);

/**
 * Set the system to activate the middlest 7 segments of the motor temperature
 * 
 * Requires:
 *      - This functions doesn't requires anything
 *        
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setTrisLedTemperature2(void);

/**
 * Set the system to activate the highest 7 segments of the motor temperature
 * 
 * Requires:
 *      - This functions doesn't requires anything
 *        
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void setTrisLedTemperature3(void);

/**
 * Returns if the preload button is pressed
 * 
 * Requires:
 *      - This functions doesn't requires anything
 *        
 * 
 * Returns:
 *      - A uint8_t variable with TRUE if the button is pressed. FALSE otherwise
 */
uint8_t getPreloadButton(void);

/**
 * Activate the fuel preload
 * 
 * Requires:
 *      - This functions doesn't requires anything
 *        
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void activatePreload(void);

/**
 * Deactivate the fuel preload
 * 
 * Requires:
 *      - This functions doesn't requires anything
 *        
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void deactivatePreload(void);

#endif
