/*
 * 413_main.c 
 * Main source code of the 413 project
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#include "413_config.h"
#include "413_adc.h"
#include "413_system.h"
#include "413_mcp.h"
#include "413_timer_interrupt.h"
#include "413_clutch_gear.h"
#include "413_security.h"
#include "413_etc_control.h"
#include "413_global_variables.h"


/**
 * Main bucle
 */
void main (void)
{
    // CAN variables
    uint8_t canFrame = 0, dataToSend[8], receivedData[8], receivedBytes; 
       
    // Initialize the oscillator system
    init_OSC();
    
    // Init the security relays of the car
    init_security();
    
    // Init the ETC motor control
    init_etcControl();  
    
    // Initialize the clutch and gear system
    init_clutch_gear();
    
    // Init the ports to the steering wheel
    init_steeringWheel();
    
    // Init the sensors systems
    init_sensors();
    
    // Init dashboard
    init_dashboard();
    
    // Initialize the bus CAN
    init_Mcp( P413_CAN_ADDRESS );
    
    // Initialize the interrupt of 1 millisecond
    init_timerInterrupt();
    
    // Set the address data for the RF System
    dataToSend[7] = P413_CAN_ADDRESS;
    
    // General loop
    while(1)
    {
        // Check if the send buffer of the MCP is free
        if ( canWeSendCANMessage() )
        {
            // Select which frame we will send now
            switch (canFrame)
            {
                case 0:
                    dataToSend[0] = global_steeringWheelClutch;   
                    dataToSend[1] = global_plausability1;
                    dataToSend[2] = global_plausability2;
                    dataToSend[3] = global_plausability3;
                    dataToSend[4] = global_plausability4;
                    dataToSend[5] = global_suspension1;  
                    break;
                case 1:
                    dataToSend[0] = global_suspension2;   
                    dataToSend[1] = global_suspension3;
                    dataToSend[2] = global_suspension4;
                    dataToSend[3] = global_oilPressure;
                    dataToSend[4] = global_oilTemperature;
                    dataToSend[5] = global_fuel;
                    break;
                case 2:
                    dataToSend[0] = global_hydraulic;   
                    dataToSend[1] = global_airPressure;
                    dataToSend[2] = global_etc1;
                    dataToSend[3] = global_etc2;
                    dataToSend[4] = global_tps1;
                    dataToSend[5] = global_tps2;                  
                    break;
                case 3:
                    dataToSend[0] = global_wheel1;   
                    dataToSend[1] = global_wheel2;
                    dataToSend[2] = global_wheel3;
                    dataToSend[3] = global_wheel4;    
                    dataToSend[4] = global_rpm;
                    dataToSend[5] = global_water_temperature;   
                    break;
                default:
                    break;
            }
            // Identify the frame to the receiver
            dataToSend[6] = canFrame;
            
            // Send the information throught the CAN bus
            send_CAN( dataToSend , 8 , RF_CAN_ADDRESS);
            
            // Increment the canFrame variable to select next frame
            if(++canFrame > 3)
                canFrame = 0;
        }
        
        // Check if we received some message
        if ( haveWeReceivedCANMessage() )
        {
            // Receive the information from the switchboard
            receive_CAN( receivedData , &receivedBytes);
            
            // Obtain the information
            global_rpm = receivedData[0];
            global_water_temperature = receivedData[1];
        }
        
        // Active segments process
        uint8_t hundreds = global_water_temperature/100;
        uint8_t tens = (global_water_temperature- (hundreds*100))/10;
        uint8_t units = global_water_temperature-(hundreds*100 + tens*10 );
        
        switch ( global_active_segments )
        {            
            case 0:
                setNumberSegments ( global_actual_gear );
                setTrisLedOnGear();
                break;
            
            case 1:
                
                setNumberSegments( units );
                setTrisLedTemperature1();
                break;
            
            case 2:
                setNumberSegments( tens );
                setTrisLedTemperature2();
                break;
            
            case 3:
                setNumberSegments( hundreds );
                setTrisLedTemperature3();
                break;
                
            default:
                break;
        }
        
        setRpm( global_rpm / 4);
        // Update the dashboard
        updateDashboard();
    } 
        
}