/*
 * 413_mcp.h 
 * MCP2515 related functions header 
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 */


#ifndef HERMES_MCP_H
#define HERMES_MCP_H

#include "413_config.h"
#include "413_spi.h"

//Order defines
#define MCP_WRITE       0x02
#define MCP_READ        0x03
#define MCP_RESET       0xC0
#define MCP_READ_STATUS 0xA0
#define MCP_RX_STATUS   0xB0
#define MCP_BIT_MODIFY  0x0A

//Action-bits defines
#define MCP_START_TRANSMIT  0x08
#define MCP_TRANSMIT_DONE   0x00
#define MCP_IS_RECEIVE_BUFFER_FULL 0x01
#define MCP_INTERRUPT_FLAGS_RX_TX 0x05
#define MCP_BUFFER_EMPTY 0x00
#define MCP_TRANSMISSIONS_ABORTED 0x00

//Memory position defines
#define MCP_BFPCTRL     0x0C
#define MCP_TXRTSCTRL   0x0D
#define MCP_CANSTAT     0x0E

#define MCP_CANCTRL     0x0F
#define MCP_CANCTRL_ABAT 0x10

#define MCP_TEC         0x1C
#define MCP_REC         0x1D
#define MCP_CNF3        0x28
#define MCP_CNF2        0x29
#define MCP_CNF1        0x2A
#define MCP_CANINTE     0x2B
#define MCP_CANINTF     0x2C
#define MCP_EFLG        0x2D
#define MCP_TXB0CTRL    0x30
#define MCP_TXB1CTRL    0x40
#define MCP_TXB2CTRL    0x50
#define MCP_RXB0CTRL    0x60
#define MCP_RXB1CTRL    0x70
#define MCP_RXF0SIDH    0x00
#define MCP_RXF0SIDL    0x01
#define MCP_RXF0EID8    0x02
#define MCP_RXF0EID0    0x03
#define MCP_RXM0SIDH    0x20
#define MCP_RXM0SIDH    0x20
#define MCP_RXM0SIDL    0x21
#define MCP_RXM0EID8    0x22
#define MCP_RXM0EID0    0x23
#define MCP_TXB0CTRK    0x30
#define MCP_TXB0SIDH    0x31
#define MCP_TXB0SIDL    0x32
#define MCP_TXB0DLC     0x35
#define MCP_TXB0D0      0x36
#define MCP_RXB0SIDH    0x61
#define MCP_RXB0SIDL    0x62
#define MCP_RXB0DLC     0x65
#define MCP_RXB0DM      0x66

// Define the interrupt external pins
#define MCP_RX_FLAG_TRIS    TRISCbits.TRISC7
#define MCP_RX_FLAG_PORT    PORTCbits.RC7
#define MCP_RX_FLAG_WPU     WPUCbits.WPUC7
#define MCP_TX_FLAG_TRIS    TRISCbits.TRISC2
#define MCP_TX_FLAG_PORT    PORTCbits.RC2
#define MCP_TX_FLAG_WPU     WPUCbits.WPUC2

// Define the 413 CAN address
#define P413_CAN_ADDRESS 0xAB

// Define the RF CAN address
#define RF_CAN_ADDRESS 69

/**
 * This function initialize the CAN system throught the MCP driver
 * 
 * Requires:
 *      - This function doesn't need any parameter
 * 
 * Returns:
 *      - This functions needs a uint8_t variable with the bus direction of
 *        the system
 */
void init_Mcp(uint16_t direction);


/**
 * This functions check if the MCP can send a message
 * 
 * Requires:
 *      - This function doesn't need any parameter
 * 
 * Returns:
 *      - This functions returns a uint8_t variable with TRUE if the MCP is able
 *        to send. FALSE otherwise
 */
inline uint8_t canWeSendCANMessage(void);


/**
 * This functions check if the MCP received a message
 * 
 * Requires:
 *      - This function doesn't need any parameter
 * 
 * Returns:
 *      - This functions returns a uint8_t variable with TRUE if the MCP 
 *        received a message. FALSE otherwise
 */
inline uint8_t haveWeReceivedCANMessage(void);


/**
 * This functions send information to the CAN bus. The maximum bytes to send
 * are 8
 * 
 * Requires:
 *      - uint8_t pointer with the information to send
 *      - uint8_t with the number of bytes you will send
 *      - uint16_t direction with the bus CAN direction you will send the
 *        information
 * 
 * Returns:
 *      - This functions returns a uint8_t variable with TRUE if the MCP was
 *        succesfully sending. FALSE otherwise
 */
uint8_t send_CAN(uint8_t *dataToSend, uint8_t nBytes, uint16_t direction);


/**
 * This functions receive information to the CAN bus. The maximum bytes to send
 * are 8
 * 
 * Requires:
 *      - uint8_t pointer where the function will replenish the information
 *      - uint8_t with the number of bytes we received
 * 
 * Returns:
 *      - This functions returns a uint8_t variable with TRUE if the MCP was
 *        succesfully receiving. FALSE otherwise
 */
uint8_t receive_CAN(uint8_t *dataToFill, uint8_t *nBytes);


#endif