/*
 * 413_sensors.c 
 * Sensors source code 
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#include "413_sensors.h"


/**
 * This function inits the sensors system. Also we will start the ADC system
 * for read the values of the analog inputs
 */
void init_sensors(void)
{
    // Init the ADC module
    init_ADC();
    
    // Program the GPIOs
    WHEEL1_TRIS = INPUT;
    WHEEL2_TRIS = INPUT;
    WHEEL3_TRIS = INPUT;
    WHEEL3_ANSEL = DIGITAL;
    WHEEL4_TRIS = INPUT;
    WHEEL4_ANSEL = DIGITAL;
}

/**
 * This function returns the value of the plausability 4 value
 */
inline uint8_t getPlaysability4Value(void)
{
    return getADCValue( P413_ADC_PLAUSABILITY_4 );
}

/**
 * This function returns the value of the plausability 3 value
 */
inline uint8_t  getPlaysability3Value(void)
{
    return getADCValue( P413_ADC_PLAUSABILITY_3 );
}

/**
 * This function returns the value of the plausability 2 value
 */
inline uint8_t  getPlaysability2Value(void)
{
    return getADCValue( P413_ADC_PLAUSABILITY_2 );
}

/**
 * This function returns the value of the plausability 1 value
 */
inline uint8_t  getPlaysability1Value(void)
{
    return getADCValue( P413_ADC_PLAUSABILITY_1 );
}

/**
 * This function returns the value of the suspension 1 value
 */
inline uint8_t  getSuspension1Value(void)
{
    return getADCValue( P413_ADC_SUSPENSION_1 );
}

/**
 * This function returns the value of the suspension 2 value
 */
inline uint8_t  getSuspension2Value(void)
{
    return getADCValue( P413_ADC_SUSPENSION_2 );
}

/**
 * This function returns the value of the suspension 3 value
 */
inline uint8_t  getSuspension3Value(void)
{
    return getADCValue( P413_ADC_SUSPENSION_3 );
}

/**
 * This function returns the value of the suspension 4 value
 */
inline uint8_t  getSuspension4Value(void)
{
    return getADCValue( P413_ADC_SUSPENSION_4 );
}

/**
 * This function returns the value of the oil pressure value
 */
inline uint8_t  getOilPressureValue(void)
{
    return getADCValue( P413_ADC_OIL_PRESSURE );
}

/**
 * This function returns the value of the oil temperature value
 */
inline uint8_t  getOilTemperatureValue(void)
{
    return getADCValue( P413_ADC_OIL_TEMPERATURE );
}

/**
 * This function returns the value of the fuel level value
 */
inline uint8_t  getFuelLevelValue(void)
{
    return getADCValue( P413_ADC_FUEL );
}

/**
 * This function returns the value of the hydraulic pressure value
 */
// Defines for calculadora the hydraulic pressure
#define AIR_PRESSURE_DEVIATION     65
#define AIR_PRESSURE_FACTOR        1.3
inline uint8_t  getHydraulicPressureValue(void)
{
    return (getADCValue( P413_ADC_HYDRAULIC ) - AIR_PRESSURE_DEVIATION) * AIR_PRESSURE_FACTOR;
}

/**
 * This function returns the value of the hydraulic pressure value
 */
inline uint8_t  getAirPressureValue(void)
{
    return getADCValue( P413_ADC_AIR_PRESSURE );
}

/**
 * This function returnsif we are detecting the wheel 1 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel1Sensor(void)
{
    return WHEEL1_PORT;
}

/**
 * This function returnsif we are detecting the wheel 2 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel2Sensor(void)
{
    return WHEEL2_PORT;
}

/**
 * This function returnsif we are detecting the wheel 3 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel3Sensor(void)
{
    return WHEEL3_PORT;
}

/**
 * This function returnsif we are detecting the wheel 4 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel4Sensor(void)
{
    return WHEEL4_PORT;  
}