/*
 * 413_sensors.h 
 * Sensors related functions 
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#ifndef _P413_SENSORS_H
#define _P413_SENSORS_H

#include "413_config.h"
#include "413_adc.h"

// Define of the GPIOs
#define WHEEL1_TRIS     TRISCbits.TRISC1
#define WHEEL1_PORT     PORTCbits.RC1
#define WHEEL2_TRIS     TRISHbits.TRISH0
#define WHEEL2_PORT     PORTHbits.RH0
#define WHEEL3_TRIS     TRISAbits.TRISA2
#define WHEEL3_ANSEL    ANSELAbits.ANSELA2
#define WHEEL3_PORT     PORTAbits.RA2
#define WHEEL4_TRIS     TRISAbits.TRISA3
#define WHEEL4_ANSEL    ANSELAbits.ANSELA3
#define WHEEL4_PORT     PORTAbits.RA3


/**
 * This function inits the sensors system. Also we will start the ADC system
 * for read the values of the analog inputs
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void init_sensors(void);

/**
 * This function returns the value of the plausability 4 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        plausability4. Remember this functions is obtained by the ADC module
 */
inline uint8_t getPlaysability4Value(void);

/**
 * This function returns the value of the plausability 3 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        plausability3. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getPlaysability3Value(void);

/**
 * This function returns the value of the plausability 2 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        plausability2. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getPlaysability2Value(void);

/**
 * This function returns the value of the plausability 1 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        plausability1. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getPlaysability1Value(void);

/**
 * This function returns the value of the suspension 1 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        suspension1. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getSuspension1Value(void);

/**
 * This function returns the value of the suspension 2 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        suspension2. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getSuspension2Value(void);

/**
 * This function returns the value of the suspension 3 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        suspension3. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getSuspension3Value(void);

/**
 * This function returns the value of the suspension 4 value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        suspension4. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getSuspension4Value(void);

/**
 * This function returns the value of the oil pressure value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        oil pressure. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getOilPressureValue(void);

/**
 * This function returns the value of the oil temperature value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        oil temperature. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getOilTemperatureValue(void);

/**
 * This function returns the value of the fuel level value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        fuel level. Remember this functions is obtained by the ADC module
 */
inline uint8_t  getFuelLevelValue(void);

/**
 * This function returns the value of the hydraulic pressure value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        hydraulic pressure. Remember this functions is obtained by the ADC
 *        module
 */
inline uint8_t  getHydraulicPressureValue(void);

/**
 * This function returns the value of the hydraulic pressure value
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with the state of the 
 *        hydraulic pressure. Remember this functions is obtained by the ADC
 *        module
 */
inline uint8_t  getAirPressureValue(void);

/**
 * This function returnsif we are detecting the wheel 1 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel1Sensor(void);

/**
 * This function returnsif we are detecting the wheel 2 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel2Sensor(void);

/**
 * This function returnsif we are detecting the wheel 3 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel3Sensor(void);

/**
 * This function returnsif we are detecting the wheel 4 angle sensor
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function returns a uint8_t variable with TRUE if we have detected
 *        the sensor, and FALSE otherwise
 */
inline uint8_t  getWheel4Sensor(void);

#endif