/*
 * 413_spi.h 
 * SPI related functions 
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#ifndef _P413_SPI_H
#define _P413_SPI_H

#include "413_config.h"

// Ports definition
// Chip select
#define CS_TRIS             TRISAbits.TRISA6
#define CS_PORT             PORTAbits.RA6
#define CS_ANSEL            ANSELAbits.ANSELA6
#define CS_LAT              LATAbits.LATA6
// Data out
#define SO_TRIS             TRISCbits.TRISC5
#define SO_PORT             PORTCbits.RC5
#define SO_LAT              LATCbits.LATC5
// Data in
#define SI_TRIS             TRISCbits.TRISC3
#define SI_PORT             PORTCbits.RC3
#define SI_LAT              LATCbits.LATC3
// Clock
#define SCK_TRIS            TRISCbits.TRISC4
#define SCK_PORT            PORTCbits.RC4
#define SCK_LAT             LATCbits.LATC4



/**
 * Initialize SPI peripheral
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void init_SPI(void);


/**
 * SPI send byte function
 * Be careful: is a block function. Returns when the transfer ends
 * 
 * Requires:
 *      - A uint8_t variable with the byte to send
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void send_SPI(uint8_t dataToSend);

/**
 * SPI receive function
 * Be careful: is a block function. Returns when the transfer ends
 * 
 * Requires:
 *      - A pointer to a uint8_t variable with the information to fill
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void read_SPI(uint8_t *dataToFill);


/**
  * This function enables the CS of the target system (in this project there
 * is only one extra system
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
inline void enable_CS();

/**
 * This function disables the CS of the target system (in this project there
 * is only one extra system
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
inline void disable_CS();


#endif