/*
 * 413_steering_wheel.c
 * Functions related with the steering wheel
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#include "413_steering_wheel.h"

/**
 * This function inits the steering wheel functions. With that we will be able
 * to know which buttons are pressing the pilot. This functions must be called
 * once before call the other functions of the steering wheel
 */
void init_steeringWheel(void)
{
    BUTTON_1_TRIS = INPUT;
    BUTTON_2_TRIS = INPUT;
    BUTTON_2_ANSEL = DIGITAL; 
    BUTTON_3_TRIS = INPUT;
    BUTTON_3_ANSEL = DIGITAL; 
    BUTTON_4_TRIS = INPUT;
    BUTTON_4_ANSEL = DIGITAL; 
    BUTTON_UP_TRIS = INPUT;
    BUTTON_UP_ANSEL = DIGITAL; 
    BUTTON_DOWN_TRIS = INPUT;
    BUTTON_DOWN_ANSEL = DIGITAL; 
}

/**
 * This function returns the state of the button 1 of the steering wheel
 */
inline uint8_t getButton1(void)
{
    return BUTTON_1_PORT;
}

/**
 * This function returns the state of the button 2 of the steering wheel
 */
inline uint8_t getButton2(void)
{
    return BUTTON_2_PORT;
}

/**
 * This function returns the state of the button 3 of the steering wheel
 */
inline uint8_t getButton3(void)
{
    return BUTTON_3_PORT;    
}

/**
 * This function returns the state of the button 4 of the steering wheel
 */
inline uint8_t getButton4(void)
{
    return BUTTON_4_PORT;    
}

/**
 * This function returns the state of the gear up button of the steering wheel
 */
inline uint8_t getGearUpButton(void)
{
    return BUTTON_UP_PORT;
}

/**
 * This function returns the state of the gear down button of the steering wheel
 */
inline uint8_t getGearDownButton(void)
{
    return BUTTON_DOWN_PORT;    
}

/**
 * This function returns the value of the clutch in the steering wheel
 */
// Defines for process the value of the clutch
#define CLUTCH_DEVIATION     50
#define CLUTCH_FACTOR        1.8
inline uint8_t getClutchValue(void)
{
    return (getADCValue( P413_ADC_STEERING_WHEEL_CLUTCH ) - CLUTCH_DEVIATION) * CLUTCH_FACTOR;
}