/*
 * 413_steering_wheel.h
 * Steering wheel related functions 
 * 
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 * 
 */

#ifndef _P413_STEERING_WHEEL_H
#define _P413_STEERING_WHEEL_H

#include "413_config.h"
#include "413_adc.h"

// Ports definition
#define BUTTON_1_TRIS       TRISHbits.TRISH3
#define BUTTON_1_PORT       PORTHbits.RH3
#define BUTTON_2_TRIS       TRISDbits.TRISD2
#define BUTTON_2_ANSEL      ANSELDbits.ANSELD2
#define BUTTON_2_PORT       PORTDbits.RD2
#define BUTTON_3_TRIS       TRISDbits.TRISD7
#define BUTTON_3_ANSEL      ANSELDbits.ANSELD7
#define BUTTON_3_PORT       PORTDbits.RD7
#define BUTTON_4_TRIS       TRISDbits.TRISD4
#define BUTTON_4_ANSEL      ANSELDbits.ANSELD4
#define BUTTON_4_PORT       PORTDbits.RD4
#define BUTTON_UP_TRIS      TRISDbits.TRISD5
#define BUTTON_UP_ANSEL     ANSELDbits.ANSELD5
#define BUTTON_UP_PORT      PORTDbits.RD5
#define BUTTON_DOWN_TRIS    TRISDbits.TRISD6
#define BUTTON_DOWN_ANSEL   ANSELDbits.ANSELD6
#define BUTTON_DOWN_PORT    PORTDbits.RD6

// Time for the fuel preload
#define PRELOAD_TIME_MS     4000

/**
 * This function inits the steering wheel functions. With that we will be able
 * to know which buttons are pressing the pilot. This functions must be called
 * once before call the other functions of the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - This function doesn't return anything
 */
void init_steeringWheel(void);

/**
 * This function returns the state of the button 1 of the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - Returns a uint8_t variable with TRUE if the button is pressed. FALSE
 *        otherwise
 */
inline uint8_t getButton1(void);

/**
 * This function returns the state of the button 2 of the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - Returns a uint8_t variable with TRUE if the button is pressed. FALSE
 *        otherwise
 */
inline uint8_t getButton2(void);

/**
 * This function returns the state of the button 3 of the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - Returns a uint8_t variable with TRUE if the button is pressed. FALSE
 *        otherwise
 */
inline uint8_t getButton3(void);

/**
 * This function returns the state of the button 4 of the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - Returns a uint8_t variable with TRUE if the button is pressed. FALSE
 *        otherwise
 */
inline uint8_t getButton4(void);

/**
 * This function returns the state of the gear up button of the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - Returns a uint8_t variable with TRUE if the button is pressed. FALSE
 *        otherwise
 */
inline uint8_t getGearUpButton(void);

/**
 * This function returns the state of the gear down button of the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - Returns a uint8_t variable with TRUE if the button is pressed. FALSE
 *        otherwise
 */
inline uint8_t getGearDownButton(void);

/**
 * This function returns the value of the clutch in the steering wheel
 * 
 * Requires:
 *      - This function no requires anything
 * 
 * Returns:
 *      - Returns TRUE if the button is pressed. FALSE otherwise
 */
inline uint8_t getClutchValue(void);

#endif