/*
 * 413_adc.h 
 * System related functions 
 *
 * Team: 
 *  Dynamics UPC Manresa
 * 
 * University: 
 *  EPSEM
 * 
 * Author:
 *  David Martn Serrano
 */

#include "413_system.h"


/**
 * This functions inits the ADC module of the microcontroller. The programmer must
 * do this function before try an ADC conversion 
 */
void init_OSC(void)
{
    // Oscillator Control Register1
    // Bit 6,5,4 ->0x4<- NOSC  - New Oscillator Source Request bits
    //                         - HFINTOSC   
    //Bit 3,2,1,0->0x0<- NDIV  - New Divider Selection Request bits
    //                         - No divider
    OSCCON1 = 0x60;
        
    // Oscillator Control Register 3
    // Bit 7 --> 0 <-- CSWHOLD - Clock Switch Hold bit
    //                         - Clock switch may proceed when the oscillator
    //                           selected by NOSC is ready; when NOSCR
    //                           becomes ?1?, the switch will occur
    // Bit 6 --> 0 <-- SOSCPWR - Secondary Oscillator Power Mode Select bit
    //                         - Secondary oscillator operating in Low-Power
    // Bit 4 --> 0 <-- ORDY    - Oscillator Ready bit
    //                         - Read only bit. No used
    // Bit 3 --> 0 <-- NOSCR   - New Oscillator is Ready bit
    //                         - Read only bit. No used
    OSCCON3 = 0x00;
    
    // Oscillator Manual Enable Register
    // Bit 7 --> 0 <-- EXTOEN  - External Oscillator Manual Request Enable bit
    //                         - EXTOSC is enabled if requested by peripheral
    // Bit 6 --> 0 <-- HFOEN   - HFINTOSC Oscillator Manual Request Enable bit
    //                         - HFINTOSC is enabled if requested by peripheral
    // Bit 5 --> 0 <-- MFOEN   - Oscillator Manual Request Enable bit
    //                         - MFINTOSC is enabled if requested by peripheral
    // Bit 4 --> 0 <-- LFOEN   - Oscillator Manual Request Enable bit
    //                         - LFINTOSC is enabled if requested by peripheral
    // Bit 3 --> 0 <-- SOSCEN  - Secondary Oscillator Manual Request Enable bit
    //                         - Secondary Oscillator is enabled if requested
    // Bit 2 --> 0 <-- ADOEN   - ADC Oscillator Manual Request Enable bit
    //                         - ADC oscillator is enabled if requested      
    OSCEN = 0x00;
    
    // HFINTOSC Frequency Selection Register
    // 64MHz selected
    OSCFRQ = 0x08;
    
    // HFINTOSC Tuning Register
    // Default frequency value
    OSCTUNE = 0x00;
}


